php.net |  support |  documentation |  report a bug |  advanced search |  search howto |  statistics |  random bug |  login
Return to Bug #42060
Patch paged-ldap-5.3 revision 2011-04-28 23:00 UTC by bryant dot david at gmail dot com
Patch api-rename.patch revision 2010-11-04 21:16 UTC by jeanseb at au-fil-du dot net
Patch php-trunk_ldap-pagination.patch revision 2010-11-04 20:47 UTC by jeanseb at au-fil-du dot net
revision 2010-11-03 21:50 UTC by jeanseb at au-fil-du dot net
revision 2010-05-21 15:27 UTC by jeanseb at au-fil-du dot net
Patch ext-ldap-review.patch revision 2010-08-04 15:54 UTC by jeanseb at au-fil-du dot net

Patch api-rename.patch for *General Issues Bug #42060

Patch version 2010-11-04 21:16 UTC

Return to Bug #42060 | Download this patch
Patch Revisions:

Developer: jeanseb@au-fil-du.net

Index: ext/ldap/tests/ldap_ctrl_paged_results_variation1.phpt
===================================================================
--- ext/ldap/tests/ldap_ctrl_paged_results_variation1.phpt	(révision 305062)
+++ ext/ldap/tests/ldap_ctrl_paged_results_variation1.phpt	(copie de travail)
@@ -1,56 +0,0 @@
---TEST--
-ldap_ldap_ctrl_paged_results() test (fetching the first page)
---CREDITS--
-Jean-Sebastien Hedde <jeanseb@au-fil-du.net>
---SKIPIF--
-<?php
-require_once('skipif.inc');
-require_once('skipifbindfailure.inc');
-?>
---FILE--
-<?php
-include "connect.inc";
-
-$link = ldap_connect_and_bind($host, $port, $user, $passwd, $protocol_version);
-insert_dummy_data($link);
-
-$dn = "dc=my-domain,dc=com";
-$filter = "(cn=*)";
-var_dump(
-	ldap_ctrl_paged_results($link, 1),
-	$result = ldap_search($link, $dn, $filter, array('cn')),
-	ldap_get_entries($link, $result)
-);
-?>
-===DONE===
---CLEAN--
-<?php
-include "connect.inc";
-
-$link = ldap_connect_and_bind($host, $port, $user, $passwd, $protocol_version);
-remove_dummy_data($link);
-?>
---EXPECTF--
-bool(true)
-resource(6) of type (ldap result)
-array(2) {
-  ["count"]=>
-  int(1)
-  [0]=>
-  array(4) {
-    ["cn"]=>
-    array(2) {
-      ["count"]=>
-      int(1)
-      [0]=>
-      string(5) "userA"
-    }
-    [0]=>
-    string(2) "cn"
-    ["count"]=>
-    int(1)
-    ["dn"]=>
-    string(28) "cn=userA,dc=my-domain,dc=com"
-  }
-}
-===DONE===
Index: ext/ldap/tests/ldap_control_paged_results_variation2.phpt
===================================================================
--- ext/ldap/tests/ldap_control_paged_results_variation2.phpt	(révision 0)
+++ ext/ldap/tests/ldap_control_paged_results_variation2.phpt	(révision 0)
@@ -0,0 +1,72 @@
+--TEST--
+ldap_ldap_control_paged_results() test (fetching the first page with a pagesize=2)
+--CREDITS--
+Jean-Sebastien Hedde <jeanseb@au-fil-du.net>
+--SKIPIF--
+<?php
+require_once('skipif.inc');
+require_once('skipifbindfailure.inc');
+?>
+--FILE--
+<?php
+include "connect.inc";
+
+$link = ldap_connect_and_bind($host, $port, $user, $passwd, $protocol_version);
+insert_dummy_data($link);
+
+$dn = "dc=my-domain,dc=com";
+$filter = "(cn=*)";
+var_dump(
+	ldap_control_paged_results($link, 2),
+	$result = ldap_search($link, $dn, $filter, array('cn')),
+	ldap_get_entries($link, $result)
+);
+?>
+===DONE===
+--CLEAN--
+<?php
+include "connect.inc";
+
+$link = ldap_connect_and_bind($host, $port, $user, $passwd, $protocol_version);
+remove_dummy_data($link);
+?>
+--EXPECTF--
+bool(true)
+resource(6) of type (ldap result)
+array(3) {
+  ["count"]=>
+  int(2)
+  [0]=>
+  array(4) {
+    ["cn"]=>
+    array(2) {
+      ["count"]=>
+      int(1)
+      [0]=>
+      string(5) "userA"
+    }
+    [0]=>
+    string(2) "cn"
+    ["count"]=>
+    int(1)
+    ["dn"]=>
+    string(28) "cn=userA,dc=my-domain,dc=com"
+  }
+  [1]=>
+  array(4) {
+    ["cn"]=>
+    array(2) {
+      ["count"]=>
+      int(1)
+      [0]=>
+      string(5) "userB"
+    }
+    [0]=>
+    string(2) "cn"
+    ["count"]=>
+    int(1)
+    ["dn"]=>
+    string(28) "cn=userB,dc=my-domain,dc=com"
+  }
+}
+===DONE===
Index: ext/ldap/tests/ldap_ctrl_paged_results_variation2.phpt
===================================================================
--- ext/ldap/tests/ldap_ctrl_paged_results_variation2.phpt	(révision 305062)
+++ ext/ldap/tests/ldap_ctrl_paged_results_variation2.phpt	(copie de travail)
@@ -1,72 +0,0 @@
---TEST--
-ldap_ldap_ctrl_paged_results() test (fetching the first page with a pagesize=2)
---CREDITS--
-Jean-Sebastien Hedde <jeanseb@au-fil-du.net>
---SKIPIF--
-<?php
-require_once('skipif.inc');
-require_once('skipifbindfailure.inc');
-?>
---FILE--
-<?php
-include "connect.inc";
-
-$link = ldap_connect_and_bind($host, $port, $user, $passwd, $protocol_version);
-insert_dummy_data($link);
-
-$dn = "dc=my-domain,dc=com";
-$filter = "(cn=*)";
-var_dump(
-	ldap_ctrl_paged_results($link, 2),
-	$result = ldap_search($link, $dn, $filter, array('cn')),
-	ldap_get_entries($link, $result)
-);
-?>
-===DONE===
---CLEAN--
-<?php
-include "connect.inc";
-
-$link = ldap_connect_and_bind($host, $port, $user, $passwd, $protocol_version);
-remove_dummy_data($link);
-?>
---EXPECTF--
-bool(true)
-resource(6) of type (ldap result)
-array(3) {
-  ["count"]=>
-  int(2)
-  [0]=>
-  array(4) {
-    ["cn"]=>
-    array(2) {
-      ["count"]=>
-      int(1)
-      [0]=>
-      string(5) "userA"
-    }
-    [0]=>
-    string(2) "cn"
-    ["count"]=>
-    int(1)
-    ["dn"]=>
-    string(28) "cn=userA,dc=my-domain,dc=com"
-  }
-  [1]=>
-  array(4) {
-    ["cn"]=>
-    array(2) {
-      ["count"]=>
-      int(1)
-      [0]=>
-      string(5) "userB"
-    }
-    [0]=>
-    string(2) "cn"
-    ["count"]=>
-    int(1)
-    ["dn"]=>
-    string(28) "cn=userB,dc=my-domain,dc=com"
-  }
-}
-===DONE===
Index: ext/ldap/tests/ldap_control_paged_results_variation3.phpt
===================================================================
--- ext/ldap/tests/ldap_control_paged_results_variation3.phpt	(révision 0)
+++ ext/ldap/tests/ldap_control_paged_results_variation3.phpt	(révision 0)
@@ -0,0 +1,100 @@
+--TEST--
+ldap_ldap_control_paged_results() test (fetching the first page then the next final page)
+--CREDITS--
+Jean-Sebastien Hedde <jeanseb@au-fil-du.net>
+--SKIPIF--
+<?php
+require_once('skipif.inc');
+require_once('skipifbindfailure.inc');
+?>
+--FILE--
+<?php
+include "connect.inc";
+
+$link = ldap_connect_and_bind($host, $port, $user, $passwd, $protocol_version);
+insert_dummy_data($link);
+
+$dn = "dc=my-domain,dc=com";
+$filter = "(cn=*)";
+$cookie = '';
+var_dump(
+	ldap_control_paged_results($link, 2, true, $cookie),
+	$result = ldap_search($link, $dn, $filter, array('cn')),
+	ldap_get_entries($link, $result),
+	ldap_control_paged_results_response($link, $result, $cookie),
+	ldap_control_paged_results($link, 20, true, $cookie),
+	$result = ldap_search($link, $dn, $filter, array('cn')),
+	ldap_get_entries($link, $result)
+);
+?>
+===DONE===
+--CLEAN--
+<?php
+include "connect.inc";
+
+$link = ldap_connect_and_bind($host, $port, $user, $passwd, $protocol_version);
+remove_dummy_data($link);
+?>
+--EXPECTF--
+bool(true)
+resource(%d) of type (ldap result)
+array(3) {
+  ["count"]=>
+  int(2)
+  [0]=>
+  array(4) {
+    ["cn"]=>
+    array(2) {
+      ["count"]=>
+      int(1)
+      [0]=>
+      string(5) "userA"
+    }
+    [0]=>
+    string(2) "cn"
+    ["count"]=>
+    int(1)
+    ["dn"]=>
+    string(28) "cn=userA,dc=my-domain,dc=com"
+  }
+  [1]=>
+  array(4) {
+    ["cn"]=>
+    array(2) {
+      ["count"]=>
+      int(1)
+      [0]=>
+      string(5) "userB"
+    }
+    [0]=>
+    string(2) "cn"
+    ["count"]=>
+    int(1)
+    ["dn"]=>
+    string(28) "cn=userB,dc=my-domain,dc=com"
+  }
+}
+bool(true)
+bool(true)
+resource(%d) of type (ldap result)
+array(2) {
+  ["count"]=>
+  int(1)
+  [0]=>
+  array(4) {
+    ["cn"]=>
+    array(2) {
+      ["count"]=>
+      int(1)
+      [0]=>
+      string(5) "userC"
+    }
+    [0]=>
+    string(2) "cn"
+    ["count"]=>
+    int(1)
+    ["dn"]=>
+    string(37) "cn=userC,cn=userB,dc=my-domain,dc=com"
+  }
+}
+===DONE===
Index: ext/ldap/tests/ldap_ctrl_paged_results_variation3.phpt
===================================================================
--- ext/ldap/tests/ldap_ctrl_paged_results_variation3.phpt	(révision 305062)
+++ ext/ldap/tests/ldap_ctrl_paged_results_variation3.phpt	(copie de travail)
@@ -1,100 +0,0 @@
---TEST--
-ldap_ldap_ctrl_paged_results() test (fetching the first page then the next final page)
---CREDITS--
-Jean-Sebastien Hedde <jeanseb@au-fil-du.net>
---SKIPIF--
-<?php
-require_once('skipif.inc');
-require_once('skipifbindfailure.inc');
-?>
---FILE--
-<?php
-include "connect.inc";
-
-$link = ldap_connect_and_bind($host, $port, $user, $passwd, $protocol_version);
-insert_dummy_data($link);
-
-$dn = "dc=my-domain,dc=com";
-$filter = "(cn=*)";
-$cookie = '';
-var_dump(
-	ldap_ctrl_paged_results($link, 2, true, $cookie),
-	$result = ldap_search($link, $dn, $filter, array('cn')),
-	ldap_get_entries($link, $result),
-	ldap_ctrl_paged_results_resp($link, $result, $cookie),
-	ldap_ctrl_paged_results($link, 20, true, $cookie),
-	$result = ldap_search($link, $dn, $filter, array('cn')),
-	ldap_get_entries($link, $result)
-);
-?>
-===DONE===
---CLEAN--
-<?php
-include "connect.inc";
-
-$link = ldap_connect_and_bind($host, $port, $user, $passwd, $protocol_version);
-remove_dummy_data($link);
-?>
---EXPECTF--
-bool(true)
-resource(%d) of type (ldap result)
-array(3) {
-  ["count"]=>
-  int(2)
-  [0]=>
-  array(4) {
-    ["cn"]=>
-    array(2) {
-      ["count"]=>
-      int(1)
-      [0]=>
-      string(5) "userA"
-    }
-    [0]=>
-    string(2) "cn"
-    ["count"]=>
-    int(1)
-    ["dn"]=>
-    string(28) "cn=userA,dc=my-domain,dc=com"
-  }
-  [1]=>
-  array(4) {
-    ["cn"]=>
-    array(2) {
-      ["count"]=>
-      int(1)
-      [0]=>
-      string(5) "userB"
-    }
-    [0]=>
-    string(2) "cn"
-    ["count"]=>
-    int(1)
-    ["dn"]=>
-    string(28) "cn=userB,dc=my-domain,dc=com"
-  }
-}
-bool(true)
-bool(true)
-resource(%d) of type (ldap result)
-array(2) {
-  ["count"]=>
-  int(1)
-  [0]=>
-  array(4) {
-    ["cn"]=>
-    array(2) {
-      ["count"]=>
-      int(1)
-      [0]=>
-      string(5) "userC"
-    }
-    [0]=>
-    string(2) "cn"
-    ["count"]=>
-    int(1)
-    ["dn"]=>
-    string(37) "cn=userC,cn=userB,dc=my-domain,dc=com"
-  }
-}
-===DONE===
Index: ext/ldap/tests/ldap_control_paged_results_variation1.phpt
===================================================================
--- ext/ldap/tests/ldap_control_paged_results_variation1.phpt	(révision 0)
+++ ext/ldap/tests/ldap_control_paged_results_variation1.phpt	(révision 0)
@@ -0,0 +1,56 @@
+--TEST--
+ldap_ldap_control_paged_results() test (fetching the first page)
+--CREDITS--
+Jean-Sebastien Hedde <jeanseb@au-fil-du.net>
+--SKIPIF--
+<?php
+require_once('skipif.inc');
+require_once('skipifbindfailure.inc');
+?>
+--FILE--
+<?php
+include "connect.inc";
+
+$link = ldap_connect_and_bind($host, $port, $user, $passwd, $protocol_version);
+insert_dummy_data($link);
+
+$dn = "dc=my-domain,dc=com";
+$filter = "(cn=*)";
+var_dump(
+	ldap_control_paged_results($link, 1),
+	$result = ldap_search($link, $dn, $filter, array('cn')),
+	ldap_get_entries($link, $result)
+);
+?>
+===DONE===
+--CLEAN--
+<?php
+include "connect.inc";
+
+$link = ldap_connect_and_bind($host, $port, $user, $passwd, $protocol_version);
+remove_dummy_data($link);
+?>
+--EXPECTF--
+bool(true)
+resource(6) of type (ldap result)
+array(2) {
+  ["count"]=>
+  int(1)
+  [0]=>
+  array(4) {
+    ["cn"]=>
+    array(2) {
+      ["count"]=>
+      int(1)
+      [0]=>
+      string(5) "userA"
+    }
+    [0]=>
+    string(2) "cn"
+    ["count"]=>
+    int(1)
+    ["dn"]=>
+    string(28) "cn=userA,dc=my-domain,dc=com"
+  }
+}
+===DONE===
 
PHP Copyright © 2001-2024 The PHP Group
All rights reserved.
Last updated: Tue Mar 19 11:01:28 2024 UTC
Index: ext/ldap/ldap.c
===================================================================
--- ext/ldap/ldap.c	(révision 305092)
+++ ext/ldap/ldap.c	(copie de travail)
@@ -2186,9 +2186,9 @@
 #endif
 
 #ifdef LDAP_CONTROL_PAGEDRESULTS
 /* {{{ proto bool ldap_ctrl_paged_results(resource link, int pagesize [, bool iscritical [, string cookie]])
    Inject paged results control*/
-PHP_FUNCTION(ldap_ctrl_paged_results) 
+PHP_FUNCTION(ldap_control_paged_results) 
 {
 	long pagesize;
 	zend_bool iscritical;
@@ -2277,9 +2277,9 @@
 }
 /* }}} */
 
 /* {{{ proto bool ldap_ctrl_paged_results_resp(resource link, resource result [, string cookie [, int estimated]])
    Extract paged results control response */
-PHP_FUNCTION(ldap_ctrl_paged_results_resp) 
+PHP_FUNCTION(ldap_control_paged_results_response) 
 {
 	zval *link, *result, *cookie, *estimated;
 	struct berval lcookie;
@@ -2551,14 +2551,14 @@
 ZEND_END_ARG_INFO()
 
 #ifdef LDAP_CONTROL_PAGEDRESULTS
-ZEND_BEGIN_ARG_INFO_EX(arginfo_ldap_ctrl_paged_results, 0, 0, 2)
+ZEND_BEGIN_ARG_INFO_EX(arginfo_ldap_control_paged_results, 0, 0, 2)
 	ZEND_ARG_INFO(0, link)
 	ZEND_ARG_INFO(0, pagesize)
 	ZEND_ARG_INFO(0, iscritical)
 	ZEND_ARG_INFO(0, cookie)
 ZEND_END_ARG_INFO();
 
-ZEND_BEGIN_ARG_INFO_EX(arginfo_ldap_ctrl_paged_results_resp, 0, 0, 2)
+ZEND_BEGIN_ARG_INFO_EX(arginfo_ldap_control_paged_results_response, 0, 0, 2)
 	ZEND_ARG_INFO(0, link)
 	ZEND_ARG_INFO(0, result)
 	ZEND_ARG_INFO(1, cookie)
@@ -2709,8 +2709,8 @@
 #endif
 
 #ifdef LDAP_CONTROL_PAGEDRESULTS
-	PHP_FE(ldap_ctrl_paged_results,							arginfo_ldap_ctrl_paged_results)
-	PHP_FE(ldap_ctrl_paged_results_resp,						arginfo_ldap_ctrl_paged_results_resp)
+	PHP_FE(ldap_control_paged_results,					arginfo_ldap_control_paged_results)
+	PHP_FE(ldap_control_paged_results_response,			arginfo_ldap_control_paged_results_response)
 #endif
 	{NULL, NULL, NULL}
 };
@@ -2186,9 +2186,9 @@
 
 #ifdef LDAP_CONTROL_PAGEDRESULTS
-/* {{{ proto bool ldap_ctrl_paged_results(resource link, int pagesize [, bool iscritical [, string cookie]])
+/* {{{ proto bool ldap_control_paged_results(resource link, int pagesize [, bool iscritical [, string cookie]])
    Inject paged results control*/
@@ -2277,9 +2277,9 @@
 /* }}} */
 
-/* {{{ proto bool ldap_ctrl_paged_results_resp(resource link, resource result [, string cookie [, int estimated]])
+/* {{{ proto bool ldap_control_paged_results_response(resource link, resource result [, string cookie [, int estimated]])
    Extract paged results control response */